#!/usr/bin/env python2
import json
import os.path
import re
import subprocess
import sys
import syslog


def log_info(msg):
    syslog.syslog(syslog.LOG_INFO | syslog.LOG_LOCAL1, msg)
    print(msg)


def update_process_name():
    sys.argv[0] = "synoame-get-app-id.py"


def validate_app_id(value):
    pattern = "^[A-Za-z0-9.]+$"
    return bool(re.match(pattern, value))


def run_plugin_to_get_app_id(plugin_path):
    output = subprocess.check_output([plugin_path, "--app-id"])

    app_id = output.strip()
    if not validate_app_id(app_id):
        log_info("[{}] is not valid app id".format(app_id))
        return None

    return app_id


def run_plugins():
    full_event = "ame_pack_install"
    plugin_dir = "/usr/local/libexec/{}".format(full_event)

    if not os.path.exists(plugin_dir):
        log_info("plugin dir {} not exists".format(plugin_dir))
        return []

    app_ids = []
    for f in os.listdir(plugin_dir):
        plugin_path = os.path.join(plugin_dir, f)
        if not os.path.isfile(plugin_path):
            continue

        try:
            app_id = run_plugin_to_get_app_id(plugin_path)
            if isinstance(app_id, str) and len(app_id) > 0:
                app_ids.append(app_id)
        except Exception as error:
            log_info("Failed to run {}, error: {}".format(plugin_path, error))

    return app_ids


if __name__ == "__main__":
    update_process_name()

    app_ids = run_plugins()

    if len(sys.argv) >= 2:
        path = sys.argv[1]
        json.dump(app_ids, open(path, "w"))
    else:
        print(json.dumps(app_ids))

    sys.exit(0)
